@@ -43,3 +43,11 @@ def set_status(cat, df):
 
 def nadlc():
     return ['angel', 'becky', 'ellis', 'lil-spot', 'olive', 'rue', 'snowball', 'stripe', 'teja', 'zelda', 'zenon', 'zoltan']
+
+
+def roi_behaviors():
+    return ['cumulative_time_in_roi_sec', 'avg_time_in_roi_sec', 'avg_vel_in_roi']
+
+
+def sniff_instances():
+    return ['t3_sniffsaline', 't5_sniffurine', 't7_sniffsaline', 't9_sniffurine']
